@@ -6,6 +6,7 @@ author: hugh@blinkybeach.com
 from procuret.ancillary.session_lifecycle import Lifecycle
 from procuret.ancillary.session_perspective import Perspective
 from procuret.data.codable import Codable
+from typing import Optional
 
 
 class AbstractSession(Codable):
@@ -15,3 +16,6 @@ class AbstractSession(Codable):
     api_key: str
     lifecycle: Lifecycle
     perspective: Perspective
+
+    acts_for_another_agent: bool
+    on_behalf_of: Optional[int]
