@@ -37,6 +37,7 @@ class ApiRequest:
     SIGNATURE_KEY_NAME = 'x-procuret-signature'
     SESSION_ID_NAME = 'x-procuret-session-id'
     USER_AGENT = 'Procuret Python ' + AGENT_VERSION
+    FORWARDED_AGENT = 'x-procuret-forwarded-agent'
 
     @classmethod
     def make(
@@ -63,6 +64,12 @@ class ApiRequest:
                 session=session
             )
 
+        if session is not None and session.acts_for_another_agent:
+            headers = cls._add_forwarded_agent_to_headers(
+                headers=headers,
+                session=session
+            )
+
         encoded_data: Optional[bytes] = None
         if data is not None:
             encoded_data = json.dumps(data).encode('utf-8')
@@ -109,6 +116,20 @@ class ApiRequest:
 
         raise NotImplementedError
 
+    @classmethod
+    def _add_forwarded_agent_to_headers(
+        cls: Type[T],
+        headers: Dict[str, str],
+        session: AbstractSession
+    ) -> Dict[str, str]:
+
+        if not session.acts_for_another_agent:
+            return headers
+        
+        headers[cls.FORWARDED_AGENT] = str(session.on_behalf_of)
+
+        return headers
+
     @classmethod
     def _headers_with_key(
         cls: Type[T],
